@@ -1,8 +1,8 @@
 """Provide a model for the Z-Wave JS node."""
 from __future__ import annotations
 
-from datetime import datetime
 import logging
+from datetime import datetime
 from typing import TYPE_CHECKING, Any, cast
 
 from ...const import (
@@ -136,9 +136,11 @@ class Node(EventBase):
         return self.data["index"]
 
     @property
-    def device_class(self) -> DeviceClass:
+    def device_class(self) -> DeviceClass | None:
         """Return the device_class."""
-        return DeviceClass(self.data["deviceClass"])
+        if (device_class := self.data.get("deviceClass")) is None:
+            return None
+        return DeviceClass(device_class)
 
     @property
     def installer_icon(self) -> int | None:
